Periodical Execution
====================

Floating Periods
----------------

.. literalinclude:: /code/conds/syntax/every.py
    :language: py

    
Fixed Periods
-------------

.. literalinclude:: /code/conds/syntax/periodical.py
    :language: py
